@@ -124,7 +124,7 @@ QString toString(Enum item, bool mnemonic)
  * @param item   item to convert
  * @return Visibility enum
  */
-Enum fromString(const QString& item)
+Enum fromString(const QString& item, bool checkUnkown)
 {
     if (item == QLatin1String("public") || item == QLatin1String("+"))
         return Public;
@@ -138,6 +138,8 @@ Enum fromString(const QString& item)
         return Protected;
     else if (item == QLatin1String("class"))
         return Private;
+    else if (checkUnkown)
+        return Unknown;
     else
         return Public;
 }
@@ -170,6 +172,8 @@ QString toString(Enum item)
             return QLatin1String("Undefined");
         case Class:
             return QLatin1String("Class");
+        case Object:
+            return QLatin1String("Object");
         case UseCase:
             return QLatin1String("UseCase");
         case Sequence:
@@ -217,6 +221,8 @@ QString toStringI18n(Enum item)
            return i18n("Deployment Diagram");
        case EntityRelationship:
            return i18n("Entity Relationship Diagram");
+        case Object:
+            return i18n("Object Diagram");
        default:
            return i18n("No Diagram");
     }
@@ -955,6 +961,12 @@ QStringList toExtensions(Enum item)
         case Uml::ProgrammingLanguage::CSharp:
             result << QLatin1String("*.cs");
             break;
+        case Uml::ProgrammingLanguage::PHP:
+            result << QLatin1String("*.php") << QLatin1String("*.inc");
+            break;
+        case Uml::ProgrammingLanguage::PHP5:
+            result << QLatin1String("*.php") << QLatin1String("*.php5") << QLatin1String("*.inc");
+            break;
         default:
             break;
     }
@@ -991,6 +1003,12 @@ QString toExtensionsDescription(Enum item)
         case Uml::ProgrammingLanguage::CSharp:
             result = QLatin1String("Source files");
             break;
+        case Uml::ProgrammingLanguage::PHP:
+            result = QLatin1String("Source files");
+            break;
+        case Uml::ProgrammingLanguage::PHP5:
+            result = QLatin1String("Source files");
+            break;
         default:
             break;
     }
@@ -1165,3 +1183,24 @@ QFont systemFont()
 }
 
 }  // end namespace Uml
+
+/**
+ * Convert floating point number string with '.' or ',' as decimal point to qreal.
+ * @param s floating point number string
+ * @return floating point number
+ * @note See https://bugs.kde.org/show_bug.cgi?id=357373 for more informations.
+ */
+qreal toDoubleFromAnyLocale(const QString &s)
+{
+    bool ok;
+    qreal value = s.toDouble(&ok);
+    if (!ok) {
+        static QLocale hungary(QLocale::Hungarian);
+        value = hungary.toDouble(s, &ok);
+        if (!ok) {
+            qCritical() << "could not read floating point number";
+            value = 0;
+        }
+    }
+    return value;
+}
