@@ -26,14 +26,13 @@
 #include <kconfig.h>
 #include <KLocalizedString>
 #include <ktip.h>
-#include <kwindowsystem.h>
 
 #if QT_VERSION >= 0x050000
+#include <KCrash>
 #include <QApplication>
 #include <QCommandLineParser>
 #endif
 
-#include <unistd.h>
 #include <stdio.h>
 
 #if QT_VERSION >= 0x050000
@@ -104,6 +103,7 @@ int main(int argc, char *argv[])
 {
 #if QT_VERSION >= 0x050000
     QApplication app(argc, argv);
+    KCrash::initialize();
 
     KLocalizedString::setApplicationDomain("umbrello");
 
@@ -114,13 +114,13 @@ int main(int argc, char *argv[])
                               "based on the industry standard Unified Modelling Language (UML).<br/>"
                               "See also <a href=’http://www.omg.org/spec/’>http://www.omg.org/spec/</a>."),
                          KAboutLicense::GPL,
-                         i18n("Copyright © 2001 Paul Hensgen,\nCopyright © 2002-2014 Umbrello UML Modeller Authors"),
+                         i18n("Copyright © 2001 Paul Hensgen,\nCopyright © 2002-2016 Umbrello UML Modeller Authors"),
                          QString(),
                          QStringLiteral("http://umbrello.kde.org"));
 #else
     KAboutData aboutData("umbrello", 0, ki18n("Umbrello UML Modeller"),
                           umbrelloVersion(), ki18n(description), KAboutData::License_GPL,
-                          ki18n("(c) 2001 Paul Hensgen, (c) 2002-2015 Umbrello UML Modeller Authors"), KLocalizedString(),
+                          ki18n("(c) 2001 Paul Hensgen, (c) 2002-2016 Umbrello UML Modeller Authors"), KLocalizedString(),
                           "http://umbrello.kde.org/");
 #endif
     aboutData.addAuthor(ki18n("Paul Hensgen"), ki18n("Author of initial version."), StringLiteral("phensgen@users.sourceforge.net"));
@@ -165,6 +165,7 @@ int main(int argc, char *argv[])
     args->process(app);
 
     aboutData.processCommandLine(args);
+    Q_INIT_RESOURCE(ui);
 #else
     KCmdLineArgs::init(argc, argv, &aboutData);
     KCmdLineOptions options;
@@ -178,6 +179,7 @@ int main(int argc, char *argv[])
     KCmdLineArgs::addCmdLineOptions(options); // Add our own options.
     KApplication app;
 #endif
+    Q_INIT_RESOURCE(icons);
 
     QPointer<UMLApp> uml;
     if (app.isSessionRestored()) {
@@ -217,7 +219,7 @@ int main(int argc, char *argv[])
             QStringList importList = args->values(IMPORT_FILES);
             if (importList.size() > 0) {
                 uml->newDocument();
-                uml->importFiles(&importList);
+                uml->importFiles(importList);
             }
         }
 #else
@@ -226,7 +228,7 @@ int main(int argc, char *argv[])
             for (int i = 0; i < args->count(); i++)
                 importList.append(args->url(i).toLocalFile());
             uml->newDocument();
-            uml->importFiles(&importList);
+            uml->importFiles(importList);
         }
 #endif
         else
